@@ -31,39 +31,24 @@
 
 #include "IDLUserDefScopeType.h"
 #include "IDLCompoundSeqElem.h"
+#include "IDLElement.h"
+#include "IDLInhibited.h"
 
-class IDLInterface : public IDLUserDefScopeType, public IDLCompoundSeqElem {
+class IDLInterfaceBase :
+	public virtual IDLTypenameInterface,
+	public IDLCompoundSeqElem,
+	public virtual IDLType {
 public:
-	typedef vector<IDLInterface *> 	BaseList;
-	BaseList 			m_bases;
-	// all bases except the ones stemming from the first direct base
-	BaseList 			m_all_mi_bases;
-	BaseList 			m_allbases;
-
-	IDLInterface(string const &id,IDL_tree node,IDLScope *parentscope = NULL)
-		: IDLUserDefScopeType(id,node,parentscope) {
-	}
-
-	bool isVariableLength() const {
-		return true;
-	}
-	bool isBaseClass(IDLInterface *iface);
-
 
 	bool is_fixed () const { return false; };
-	
-	////////////////////////////////////////////
+		
 	// Creating typedefs
-
 	void typedef_decl_write (ostream          &ostr,
 				 Indent           &indent,
 				 IDLCompilerState &state,
 				 const IDLTypedef &target,
 				 const IDLTypedef *active_typedef = 0) const;
 	
-	////////////////////////////////////////////
-	// Stubs
-
 	// Stub declaration
 	string stub_decl_arg_get (const string     &cpp_id,
 				  IDL_param_attr    direction,
@@ -102,9 +87,6 @@ public:
 				 Indent           &indent,
 				 const IDLTypedef *active_typedef = 0) const;
 	
-	////////////////////////////////////////////
-	// Skels
-
 	// Skel declaration
 	string skel_decl_arg_get (const string     &c_id,
 				  IDL_param_attr    direction,
@@ -142,10 +124,7 @@ public:
 	void skel_impl_ret_post (ostream          &ostr,
 				 Indent           &indent,
 				 const IDLTypedef *active_typedef = 0) const;
-
-	////////////////////////////////////////////
-	// Members of compund types
-
+	
 	// Compund declaration
 	string get_cpp_member_typename (const IDLTypedef *active_typedef = 0) const;
 	string get_c_member_typename   (const IDLTypedef *active_typedef = 0) const;
@@ -181,21 +160,6 @@ public:
 				    const string     &cpp_id,
 				    const string     &c_id,
 				    const IDLTypedef *active_typedef = 0) const;
-	
-public:
-	virtual string get_cpp_stub_identifier () const;
-	virtual string get_cpp_stub_typename () const;
-	virtual string get_cpp_stub_method_prefix () const;
-
-	string get_cpp_poa_identifier () const;
-	string get_cpp_poa_typename () const;
-	string get_cpp_poa_method_prefix () const;
-
-	void get_cpp_poa_namespace (string &ns_begin, string &ns_end) const;
-
-	string get_c_poa_typename () const;
-	string get_c_poa_epv  () const;
-	string get_c_poa_vepv () const;
 
 	string get_cpp_typename_ptr () const;
 	string get_cpp_typename_var () const;
@@ -207,6 +171,65 @@ public:
 	string get_cpp_identifier_mgr () const;
 	string get_cpp_identifier_out () const;
 
+	virtual string get_cpp_stub_identifier () const;
+	virtual string get_cpp_stub_typename () const;
+	virtual string get_cpp_stub_method_prefix () const;
+};
+
+typedef IDLInhibited<IDLInterfaceBase> IDLInterfaceInhibited;
+
+class IDLInterface :
+	public IDLUserDefScopeType,
+	public IDLInterfaceBase {
+public:
+	enum DclDefnType {
+		forward_dcl,
+		definition
+	};
+
+	typedef vector<IDLInterface *> 	BaseList;
+	BaseList 			m_bases;
+	// all bases except the ones stemming from the first direct base
+	BaseList 			m_all_mi_bases;
+	BaseList 			m_allbases;
+
+	IDLInterface(string const &id,IDL_tree node,IDLScope *parentscope = NULL, DclDefnType dcl = definition)
+		: IDLUserDefScopeType(id,node,parentscope, (dcl == definition) ? replace : no_replace) {
+	}
+
+	bool isVariableLength() const {
+		return true;
+	}
+	bool isBaseClass(IDLInterface *iface);
+
+
+	
+	
+	////////////////////////////////////////////
+	// Stubs
+
+	
+	////////////////////////////////////////////
+	// Skels
+
+
+	////////////////////////////////////////////
+	// Members of compund types
+
+	
+public:
+
+	string get_cpp_poa_identifier () const;
+	string get_cpp_poa_typename () const;
+	string get_cpp_poa_method_prefix () const;
+
+	void get_cpp_poa_namespace (string &ns_begin, string &ns_end) const;
+
+	string get_c_poa_typename () const;
+	string get_c_poa_epv  () const;
+	string get_c_poa_vepv () const;
+
+
 public:
 	void common_write_typedefs (ostream &ostr, Indent  &indent) const;
 
