@@ -32,17 +32,15 @@
 #include "IDLType.h"
 #include "IDLCompound.h"
 #include "IDLCompoundSeqElem.h"
+#include "IDLInhibited.h"
 
-class IDLStruct: public IDLCompound, public virtual IDLType, public IDLCompoundSeqElem
+class IDLStructBase :
+	public virtual IDLTypenameInterface,
+	public IDLCompoundSeqElem,
+	public virtual IDLType
 {
 public:
-	IDLStruct(const string &id,
-		  IDL_tree      node,
-		  IDLScope     *parentscope = 0);
-
-	bool isType () { return true; };
-	bool conversion_required () const;
-	bool is_fixed () const;
+	virtual bool conversion_required () const = 0;
 	
 	////////////////////////////////////////////
 	// Creating typedefs
@@ -175,6 +173,25 @@ public:
 				   const IDLTypedef *active_typedef = 0) const;
 };
 
+class IDLStructInhibited : public IDLInhibited<IDLStructBase> {
+public:
+	IDLStructInhibited(IDL_tree s) : IDLInhibited<IDLStructBase>(s) { }
+	bool is_fixed () const { ORBITCPP_NYI("IDLStructInhibited::is_fixed"); }
+	bool conversion_required () const {  ORBITCPP_NYI("IDLStructInhibited::conversion_required"); }
+};
+
+class IDLStruct :
+	public IDLCompound,
+	public IDLStructBase
+{
+public:
+	IDLStruct(const string &id,
+		  IDL_tree      node,
+		  IDLScope     *parentscope = 0);
+	bool is_fixed () const;
+	bool conversion_required () const;
+};
+
 #endif //ORBITCPP_TYPES_IDLSTRUCT
 
 
