@@ -36,12 +36,8 @@ class IDLUserDefScopeType
   public virtual IDLType
 {
 public:
-	IDLUserDefScopeType(string const &id,IDL_tree node,IDLScope *parentscope = NULL)
-		: IDLScope(id,node,parentscope) {}
-
-	bool isType() {
-		return true;
-	}
+	IDLUserDefScopeType(string const &id,IDL_tree node,IDLScope *parentscope = NULL, ReplaceType update = no_replace)
+		: IDLScope(id,node,parentscope,0,update) {}
 };
 
 #endif //ORBITCPP_TYPES_IDLUSERDEFSCOPETYPE
